package com.example.demo.Service;

import com.example.demo.Controller.GameController;
import com.example.demo.Entity.Game;
import com.example.demo.Entity.User;
import com.example.demo.Repository.UserRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import java.util.Collection;

@Service
public class UserService {

    private static final Logger logger = LoggerFactory.getLogger(UserService.class);
    private UserRepository userRepository;
    private GameService gameService;

    @Autowired
    public UserService(UserRepository userRepository, GameService gameService) {
        this.userRepository = userRepository;
        this.gameService = gameService;
    }

    public User createUser(User user){
        logger.info("Creating user...");
        user = this.userRepository.save(user);
        return user;
    }

    public Collection<User> findAllUsers(){

        return this.userRepository.findAll();
    }

    public User findByEmail(String email){

        return this.userRepository.findByEmail(email);
    }



    public User findUserById(Long userId) {
        User user = this.userRepository.findById(userId).get();
        return user;
    }

    public User updateUserName(String newName, Long userId) {
        User updatedUser = userRepository.getOne(userId);
        updatedUser.setName(newName);
        return this.userRepository.save(updatedUser);
    }

    public User deleteUser(Long userId) {
        User deleteUser = userRepository.getOne(userId);
        userRepository.delete(deleteUser);
        return deleteUser;
    }

    public User updateUserLibrary(Long gameId, Long userId) {
        User user = userRepository.getOne(userId);
        Game game = gameService.findGameById(gameId);
        user.addGame(game);
        return userRepository.save(user);
    }

    public Collection<Game> getAllUsersGames(Long userId){
        return userRepository.findAllGamesById(userId);
    }

}
