package com.example.demo.ServiceTest;


import com.example.demo.Entity.Game;
import com.example.demo.Entity.User;
import com.example.demo.Repository.UserRepository;
import com.example.demo.Service.GameService;
import com.example.demo.Service.UserService;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Optional;

public class UserServiceTest {

    @Mock
    private UserRepository userRepository;
    @Mock
    private GameService gameService;

    @InjectMocks
    private UserService userService;

    @Before
    public void setUp(){
        //does dependency injections
        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void createUserTest(){
        User nafis = new User("nafis", "nafis@fake.com", "1234");
        Mockito.when(userRepository.save(nafis)).thenReturn(nafis);

        User actual = userService.createUser(nafis);

        Assert.assertEquals(nafis, actual);
    }

    @Test
    public void createUserTest1(){
        User nafis = new User("nafis", "nafis@fake.com", "1234");
        User lawrence = new User("law", "law@fake.com", "4567");
        Mockito.when(userRepository.save(lawrence)).thenReturn(lawrence);

        User actual = userService.createUser(nafis);

        Assert.assertNotEquals(nafis, actual);
    }


    @Test
    public void findAllUsersTest() {
        Collection<User> users = new ArrayList<>();
        User nafis = new User("nafis", "nafis@fake.com", "1234");
        User lawrence = new User("law", "law@fake.com", "4567");
        users.add(nafis);
        users.add(lawrence);
        Mockito.when(userRepository.findAll()).thenReturn((List<User>) users);

        Collection<User> actual = userService.findAllUsers();

        Assert.assertEquals(actual, users);
    }

    @Test
    public void findUserByIdTest() {
        User nafis = new User("nafis", "nafis@fake.com", "1234");
        System.out.println(nafis.getName());
        Mockito.when(userRepository.findById(1L)).thenReturn(Optional.of(nafis));
        User actual = userService.findUserById(1L);

        Assert.assertEquals(actual, nafis);
    }

    @Test
    public void updateUserNameTest() {
        User nafis = new User("nafis", "nafis@fake.com", "1234");

        Mockito.when(userRepository.getOne(1L)).thenReturn(nafis);
        Mockito.when(userRepository.save(nafis)).thenReturn(nafis);
        User actual = userService.updateUserName("nafifi", 1L);

        Assert.assertEquals(actual.getName(), "nafifi");
    }

    @Test
    public void deleteUserTest() {
        User nafis = new User("nafis", "nafis@fake.com", "1234");

        Mockito.when(userRepository.getOne(1L)).thenReturn(nafis);
        Mockito.doNothing().when(userRepository).delete(nafis);

        User actual = userService.deleteUser(1L);
        Assert.assertEquals(actual, nafis);

    }

//    @Test
//    public void updateUserLibraryTest() {
//        User nafis = new User("nafis", "nafis@fake.com", "1234");
//        Game metroid = new Game("metroid","nintendo", "nes","");
//        Game metroid2 = new Game("metroid2","nintendo", "gba","");
//
//        Mockito.when(userRepository.getOne(1L)).thenReturn(nafis);
//        Mockito.when(gameService.findGameById(1L)).thenReturn(metroid);
//        Mockito.when(userRepository.save(nafis)).thenReturn(nafis);
//
//        Assert.assertTrue(userService.updateUserLibrary(1L,1L).getGameLibrary().contains(metroid));
//    }
}
